==> download.php?file=zips%2Fold%2Fwindows%2FOpenVSP-3.37.2-win64-Python3.8.zip: OpenVSP-3.37.2-win64/python/AvlPy/setup.py <==
# Copyright (c) 2020 Uber Technologies, Inc.

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

from setuptools import setup, Extension
from setuptools.command.build_ext import build_ext
import os
import shutil
import subprocess
import glob

extension_name = "avlpy.bin.avl"

setup(
    name='avlpy',
    version='0.1',
    packages=['avlpy'],
    url='',
    license='MIT',
    author='',
    author_email='',
    description='AVL with python wrapper',
    install_requires=['airfoils', 'numpy', 'scipy', 'utilities', 'fortranformat'],
)

==> download.php?file=zips%2Fold%2Fwindows%2FOpenVSP-3.44.1-win64-Python3.9.zip: OpenVSP-3.44.1-win64/python/AvlPy/setup.py <==
# Copyright (c) 2020 Uber Technologies, Inc.

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

from setuptools import setup, Extension
from setuptools.command.build_ext import build_ext
import os
import shutil
import subprocess
import glob

extension_name = "avlpy.bin.avl"

setup(
    name='avlpy',
    version='0.1',
    packages=['avlpy'],
    url='',
    license='MIT',
    author='',
    author_email='',
    description='AVL with python wrapper',
    install_requires=['vsp_airfoils', 'numpy', 'scipy', 'utilities', 'fortranformat'],
)
